"""HBS - Harmonic Beltrami Signature package.

A Python library for complex analysis and conformal mapping computations.
"""

from .hbs import get_hbs, reconstruct_from_hbs
from . import utils
from . import boundary
from . import mesh
from . import conformal_welding
